@@ -276,7 +276,7 @@ ThreadAssign (Value ref, Value v, Bool initialize)
 	RaiseStandardException (exception_invalid_binop_values, 2, ref, v);
     else if (RefConstant(ref) && !initialize)
 	RaiseStandardException (exception_readonly_box, 1, v);
-    else if (ref->ref.element >= ref->ref.box->nvalues)
+    else if (ref->ref.element < 0 || (unsigned long) ref->ref.element >= ref->ref.box->nvalues)
 	RaiseStandardException (exception_invalid_array_bounds, 2,
 				NewInt(ref->ref.element), v);
     else if (!TypeCompatibleAssign (RefType (ref), v))
@@ -330,6 +330,7 @@ ThreadArrayInd (Value thread, Bool resizable, Value dim, Type *type)
     int	    ndim = ArrayLimits(a)[0];
     int	    *dims;
 
+    (void) thread;
     dims = AllocateTemp (ndim * sizeof (int));
     for (i = 0; i < ndim; i++)
     {
@@ -423,6 +424,7 @@ ThreadArrayReplicate (Value thread, Value array, int dim, int start)
     int		total;
     Value	*elements;
 
+    (void) thread;
     for (i = 0; i < dim; i++)
 	dimsize *= ArrayDims(&array->array)[i];
     start = start - dimsize;
@@ -443,7 +445,7 @@ ThreadArrayReplicate (Value thread, Value array, int dim, int start)
 
 void
 ThreadStackDump (Value thread);
-    
+
 static Value
 ThreadArrayInit (Value thread, Value value, AInitMode mode, 
 		 int dim, int *stack, InstPtr *next)
@@ -453,6 +455,7 @@ ThreadArrayInit (Value thread, Value value, AInitMode mode,
     int	    i;
     int	    ndim;
 
+    (void) next;
     if (aborting)
 	RETURN(value);
     switch (mode) {
@@ -468,7 +471,7 @@ ThreadArrayInit (Value thread, Value value, AInitMode mode,
 	array = Stack(ndim+1);
 	if (ValueInt(Stack(dim+1)) == ArrayDims(&array->array)[dim])
 	    break;
-	/* fall through ... */
+	__NICKLE_FALLTHROUGH;
     case AInitModeElement:
         ndim = ValueInt(Stack(0));
 	array = Stack(ndim+1);
@@ -853,7 +856,8 @@ static Value
 ThreadOpDot (Value thread, Value value, Atom atom, Bool fetch)
 {
     Value   v;
-    
+
+    (void) thread;
     switch (ValueTag(value)) {
     default:
 	RaiseStandardException (exception_invalid_unop_value, 1, value);
@@ -1165,7 +1169,7 @@ ThreadsRun (Value thread, Value lex)
 		    break;
 		case OpReturnVoid:
 		    value = Void;
-		    /* fall through */
+		    __NICKLE_FALLTHROUGH;
 		case OpReturn:
 		    if (!thread->thread.continuation.frame)
 		    {
@@ -1195,7 +1199,7 @@ ThreadsRun (Value thread, Value lex)
 		    break;
 		case OpGlobalRef:
 		    ThreadBoxCheck (inst->box.box, 0);
-		    /* fall through... */
+		    __NICKLE_FALLTHROUGH;
 		case OpGlobalRefStore:
 		    value = NewRef (inst->box.box, 0);
 		    break;
@@ -1344,7 +1348,7 @@ ThreadsRun (Value thread, Value lex)
 			break;
 		    }
 		    value = RefValueGet(value);
-		    /* fall through ... */
+		    __NICKLE_FALLTHROUGH;
 		case OpDot:
 		case OpDotRef:
 		case OpDotRefStore:
