@@ -28,7 +28,12 @@
 #endif
 
 #ifdef HAVE_LIBREADLINE
-#include READLINE_H
+#ifdef HAVE_LIBEDIT
+#include <readline.h>
+#else
+#include <readline/readline.h>
+#include <readline/history.h>
+#endif
 #endif
 
 int	stdin_interactive;
@@ -181,6 +186,7 @@ stop (int sig)
 {
     sigset_t	set, oset;
 
+#ifdef HAVE_LIBREADLINE
     if (stdin_in_readline) {
 #ifdef HAVE_RL_ECHO_SIGNAL_CHAR
 	rl_echo_signal_char(sig);
@@ -189,6 +195,7 @@ stop (int sig)
 	rl_cleanup_after_signal();
 #endif
     }
+#endif
 
     IoStop ();
     releaseSignal (sig);
@@ -212,6 +219,7 @@ stop (int sig)
 void
 die (int sig)
 {
+#ifdef HAVE_LIBREADLINE
     if (stdin_in_readline) {
 #ifdef HAVE_RL_FREE_LINE_STATE
 	rl_free_line_state();
@@ -220,6 +228,7 @@ die (int sig)
 	rl_cleanup_after_signal();
 #endif
     }
+#endif
     IoStop ();
     _exit (sig);
 }
